Changelog
---------

0.2.1 (2015-03-20)
------------------
* Change default request timeout to 5 seconds

0.2.0 (2015-03-19)
------------------

* Multiple languages support
* English and Russian translations
* Usable url for iOS review


0.1.0 (2015-03-09)
------------------

* Initial release
